# cordo
Coordinates Validation python library




## Installation

```bash
pip install cordo
```



# Usage

## Get Coordinates for specific City
```bash
from cordo.cord import cord
```
### Get Coordinates

```bash
cord("Lahore")
```

### List a cities coordinates on the basis of country
```bash
country_cords('Pakistan') 
```

